@@ -1,6 +1,7 @@
 from abc import ABCMeta, abstractmethod
 from senkalib.caaj_journal import CaajJournal
 from senkalib.chain.transaction import Transaction
+from typing import List
 
 class CaajPlugin(metaclass=ABCMeta):
   chain = None
@@ -10,5 +11,5 @@ class CaajPlugin(metaclass=ABCMeta):
     pass
 
   @abstractmethod
-  def get_caajs(cls, address:str, transaction:Transaction) -> CaajJournal:
+  def get_caajs(cls, address:str, transaction:Transaction) -> List[CaajJournal]:
     pass
\ No newline at end of file
